==> ipstack-8.x-1.0.tar.gz: ipstack/src/Ipstack.php <==
<?php

namespace Drupal\ipstack;

/**
 * @file
 * Contains \Drupal\ipstack\Ipstack.
 */

use Drupal\Core\Url;
use GuzzleHttp\Client;

/**
 * Class Ipstack.
 *
 * Provides ipstack.com API.
 *
 * @ingroup ipstack
 */
class Ipstack {

  /**
    * IP address.
    *
    * @var string
    */
  protected $ip;

  /**
    * Ipstack options.
    *
    * @var array
    */
  protected $options;

  /**
   * Ipstack constructor.
   *
   * @param string $ip
   *   IP address.
   * @param array $options
   *   Ipstack options.
   */
  public function __construct($ip = '', $options = array()) {
    $this->setIp($ip);
    $this->setOptions($options);
  }

  /**
   * Set IP address.
   *
   * @param string $ip
   *   IP address.
   */
  public function setIp($ip) {
    $this->ip = $ip;
  }

  /**
   * Set ipstack options. (config value if empty).
   *
   * @param string $options
   *   Ipstack options.
   */
  public function setOptions($options) {
    if (empty($options['access_key'])) {
      $access_key = \Drupal::configFactory()->get('ipstack.settings')->get('access_key');
      $options['access_key'] = $access_key;
    }
    $this->options = $options;
  }

 /**
   * Get ipstack URL.
   *
   * @return string
   *   Ipstack URL for data retrieving.
   */
  public function getUrl() {
    $url_options = ['absolute' => TRUE, 'query' => $this->options];
    $url = Url::fromUri("http://api.ipstack.com/" . $this->ip, $url_options);
    return $url->toString();
  }

  /**
   * Get ipstack data.
   *
   * @return object
   *   Ipstack data.
   */
  public function getData() {
    // Access Key is required.
    if (empty($this->options['access_key'])) {
      return FALSE;
    }

    // If IP is empty set current user IP.
    if (empty($this->ip)) {
      $this->ip = \Drupal::request()->getClientIp();
    }

    // Get data from api.ipstack.com .
    $client = \Drupal::httpClient();
    $responce = $client->get($this->getUrl());
    $status = $responce->getStatusCode();
    if ($status != 200) return FALSE;
    $data = json_decode($responce->getBody());

    return $data;
  }

}

==> ipstack-8.x-1.1.tar.gz: ipstack/src/Ipstack.php <==
<?php

namespace Drupal\ipstack;

/**
 * @file
 * Contains \Drupal\ipstack\Ipstack.
 */

use Drupal\Core\Url;

/**
 * Class Ipstack.
 *
 * Provides ipstack.com API.
 *
 * @ingroup ipstack
 */
class Ipstack {

  /**
   * IP address.
   *
   * @var string
   */
  protected $ip;

  /**
   * Ipstack options.
   *
   * @var array
   */
  protected $options;

  /**
   * Ipstack constructor.
   *
   * @param string $ip
   *   IP address.
   * @param array $options
   *   Ipstack options.
   */
  public function __construct($ip = '', array $options = []) {
    $this->setIp($ip);
    $this->setOptions($options);
  }

  /**
   * Set IP address.
   *
   * @param string $ip
   *   IP address.
   */
  public function setIp($ip) {
    $this->ip = trim($ip);

    // If IP is empty set current user IP.
    if (empty($this->ip)) {
      $this->ip = \Drupal::request()->getClientIp();
    }
  }

  /**
   * Set ipstack options. (config value if empty).
   *
   * @param string $options
   *   Ipstack options.
   */
  public function setOptions($options) {
    if (empty($options['access_key'])) {
      $access_key = \Drupal::configFactory()->get('ipstack.settings')->get('access_key');
      $options['access_key'] = $access_key;
    }
    $this->options = $options;
  }

  /**
   * Get ipstack URL.
   *
   * @return string
   *   Ipstack URL for data retrieving.
   */
  public function getUrl() {
    $url_options = ['absolute' => TRUE, 'query' => $this->options];
    $url = Url::fromUri("http://api.ipstack.com/" . $this->ip, $url_options);
    return $url->toString();
  }

  /**
   * Get ipstack data.
   *
   * @return object
   *   Ipstack data.
   */
  public function getData() {
    // Access Key is required.
    if (empty($this->options['access_key'])) {
      return FALSE;
    }

    // Get data from api.ipstack.com .
    $client = \Drupal::httpClient();
    $responce = $client->get($this->getUrl());
    $status = $responce->getStatusCode();
    if ($status != 200) {
      return FALSE;
    }
    $data = json_decode($responce->getBody());

    return $data;
  }

}
